###################################################
### chunk number 1: loadLibs
###################################################
#line 98 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
library(caret)
library(kernlab)
library(gbm)
library(ipred)
library(grid)
library(randomForest)
data(BloodBrain)
data(mdrr)

getInfo <- function(what = "Suggests")
{
  text <- packageDescription("caret")[what][[1]]
  text <- gsub("\n", ", ", text, fixed = TRUE)
  text <- gsub(">=", "$\\\\ge$", text, fixed = TRUE)
  eachPkg <- strsplit(text, ", ", fixed = TRUE)[[1]]
  eachPkg <- gsub(",", "", eachPkg, fixed = TRUE)
  out <- paste("\\\\pkg{", eachPkg[order(tolower(eachPkg))], "}", sep = "")
  paste(out, collapse = ", ")
}


###################################################
### chunk number 2: preProc
###################################################
#line 225 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
print(ncol(mdrrDescr))
nzv <- nearZeroVar(mdrrDescr)
filteredDescr <- mdrrDescr[, -nzv]

print(ncol(filteredDescr))

descrCor <- cor(filteredDescr)
highlyCorDescr <- findCorrelation(descrCor, cutoff = .75)
filteredDescr <- filteredDescr[,-highlyCorDescr]

print(ncol(filteredDescr))

set.seed(1)
inTrain <- sample(seq(along = mdrrClass), length(mdrrClass)/2)

trainDescr <- filteredDescr[inTrain,]
testDescr <- filteredDescr[-inTrain,]
trainMDRR <- mdrrClass[inTrain]
testMDRR <- mdrrClass[-inTrain]

print(length(trainMDRR))
print(length(testMDRR))


###################################################
### chunk number 3: setup
###################################################
#line 259 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
fitControl <- trainControl(## 10-fold CV
                           method = "repeatedcv",
                           number = 10,
                           ## repeated three times
                           repeats = 3,
                           ## Save all the resampling results
                           returnResamp = "all")


###################################################
### chunk number 4: mdrrModel1
###################################################
#line 280 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
gbmFit1 <- train(trainDescr, trainMDRR, 
                 method = "gbm", 
                 trControl = fitControl,
                 ## This last option is actually one
                 ## for gbm() that passes through
                 verbose = FALSE)
gbmFit1


###################################################
### chunk number 5: getSeqMods
###################################################
#line 316 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
seqModList <- paste(paste("\\\\pkg{", unique(subset(modelLookup(), seq)$model), "}", sep = ""), collapse = ", ")


###################################################
### chunk number 6: mdrrGrid
###################################################
#line 1158 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
gbmGrid <-  expand.grid(.interaction.depth = c(1, 3), 
                        .n.trees = c(10, 50, 100, 150, 200, 250, 300), 
                        .shrinkage = 0.1)


###################################################
### chunk number 7: mdrrGridFit
###################################################
#line 1164 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
set.seed(3)
gbmFit2 <- train(trainDescr, trainMDRR, 
                 method = "gbm", 
                 trControl = fitControl, 
                 verbose = FALSE, 
                 ## Now specify the exact models 
                 ## to evaludate:
                 tuneGrid = gbmGrid)
gbmFit2


###################################################
### chunk number 8: summaryFunc
###################################################
#line 1311 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
twoClassSummary


###################################################
### chunk number 9: setup
###################################################
#line 1319 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
fitControl <- trainControl(method = "repeatedcv",
                           number = 10,
                           repeats = 3,
                           returnResamp = "all",
                           ## Estimate class probabilities
                           classProbs = TRUE,
                           ## Evaluate performance using 
                           ## the following function
                           summaryFunction = twoClassSummary)


###################################################
### chunk number 10: reTune
###################################################
#line 1331 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
set.seed(3)
gbmFit3 <- train(trainDescr, trainMDRR, 
                 method = "gbm", 
                 trControl = fitControl, 
                 verbose = FALSE, 
                 tuneGrid = gbmGrid,
                 ## Specify which metric to optimize
                 metric = "ROC")
gbmFit3


###################################################
### chunk number 11: bestGBM
###################################################
#line 1391 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
printSelected <- function(x)
  {
    tmp <- x$bestTune
    names(tmp) <- gsub(".", " ", names(tmp), fixed = TRUE)
    tmp <- paste(names(tmp), "=", tmp)
    paste(tmp, collapse = ", ")
  }
getTrainPerf <- function(x)
  {
    bst <- x$bestTune
    names(bst) <- substring(names(bst), 2)
    merge(bst, x$results)
  }


###################################################
### chunk number 12: tolerance
###################################################
#line 1419 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
whichTwoPct <- tolerance(gbmFit3$results, "ROC", 2, TRUE)  
cat("best model within 2 pct of best:\n")
gbmFit3$results[whichTwoPct,]


###################################################
### chunk number 13: makePlots
###################################################
#line 1441 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
pdf(paste(getwd(), "/gbm1.pdf", sep = ""), width = 5, height = 5)
   trellis.par.set(caretTheme(), warn = FALSE)
   print(plot(gbmFit3))
dev.off()
pdf(paste(getwd(), "/gbm2.pdf", sep = ""), width = 5, height = 5)
   trellis.par.set(caretTheme(), warn = FALSE)
   print(plot(gbmFit3, metric = "Spec"))
dev.off()
pdf(paste(getwd(), "/gbm3.pdf", sep = ""), width = 8, height = 4)
   trellis.par.set(caretTheme(), warn = FALSE)
   print(plot(gbmFit3, meric = "ROC", plotType = "level"))
dev.off()



###################################################
### chunk number 14: bhExample
###################################################
#line 1560 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
library(mlbench)
data(BostonHousing)
# we could use the formula interface too
bhDesignMatrix <-  model.matrix(medv ~. - 1, BostonHousing)


###################################################
### chunk number 15: bhSplit
###################################################
#line 1571 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
set.seed(4)
inTrain <- createDataPartition(BostonHousing$medv, p = .8, list = FALSE, times = 1)
trainBH <- bhDesignMatrix[inTrain,]
testBH <- bhDesignMatrix[-inTrain,]

trainMedv <- BostonHousing$medv[inTrain]
testMedv <- BostonHousing$medv[-inTrain]


###################################################
### chunk number 16: bhModels
###################################################
#line 1585 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
set.seed(5)
plsFit <- train(trainBH, trainMedv, 
                "pls", 
                preProcess = c("center", "scale"),
                tuneLength = 10, 
                trControl = trainControl(verboseIter = FALSE,
                                         returnResamp = "all"))
set.seed(5)
marsFit <- train(trainBH, trainMedv, 
                 "earth", 
                 tuneLength = 10, 
                 trControl = trainControl(verboseIter = FALSE,
                                          returnResamp = "all"))



###################################################
### chunk number 17: marPrediction1
###################################################
#line 1606 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
marsPred1 <- predict(marsFit$finalModel, newdata = testBH)
head(marsPred1)


###################################################
### chunk number 18: marsPrediction2
###################################################
#line 1613 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
marsPred2 <- predict(marsFit, newdata = testBH)
head(marsPred2)


###################################################
### chunk number 19: bhPrediction1
###################################################
#line 1629 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
bhModels <- list(pls = plsFit, mars = marsFit)

bhPred1 <- predict(bhModels, newdata = testBH)
str(bhPred1)


###################################################
### chunk number 20: bhPrediction1
###################################################
#line 1642 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
allPred <- extractPrediction(bhModels,
                             testX = testBH,
                             testY = testMedv)
testPred <- subset(allPred, dataType == "Test")
head(testPred)

ddply(testPred, .(model), defaultSummary)



###################################################
### chunk number 21: mdrConfusion
###################################################
#line 1700 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
mdrrPredictions <- extractPrediction(list(gbmFit3), testX = testDescr, testY = testMDRR)
mdrrPredictions <- mdrrPredictions[mdrrPredictions$dataType == "Test",]
sensitivity(mdrrPredictions$pred, mdrrPredictions$obs)
confusionMatrix(mdrrPredictions$pred, mdrrPredictions$obs)


###################################################
### chunk number 22: resampCM
###################################################
#line 1755 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
confusionMatrix(gbmFit3)


###################################################
### chunk number 23: mdrrROC
###################################################
#line 1776 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
mdrrProbs <- extractProb(list(gbmFit3), testX = testDescr, testY = testMDRR)
mdrrProbs <- mdrrProbs[mdrrProbs$dataType == "Test",]
mdrrROC <- roc(mdrrProbs$Active, mdrrProbs$obs)
aucRoc(mdrrROC)


###################################################
### chunk number 24: mdrrPlots
###################################################
#line 1797 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
pdf(paste(getwd(), "/roc.pdf", sep = ""), width = 6.5, height = 7)
   plot(1 - mdrrROC[,"specificity"], mdrrROC[, "sensitivity"], type = "s", xlab = "1 - Specificity", ylab = "Sensitivity")
   abline(0,1, col = "grey", lty = 2)
dev.off()

pdf(paste(getwd(), "/gbmProbs.pdf", sep = ""), width = 9, height = 7)
   trellis.par.set(caretTheme(), warn = FALSE)
   print(plotClassProbs(mdrrProbs))
dev.off()


###################################################
### chunk number 25: bhPredPlot
###################################################
#line 1827 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
pdf("bhPredPlot.pdf", width = 8, height = 5)
trellis.par.set(caretTheme(), warn = FALSE)
print(plotObsVsPred(testPred))
dev.off()


###################################################
### chunk number 26: makeResampPlots
###################################################
#line 1874 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
pdf(paste(getwd(), "/marsXY.pdf", sep = ""), width = 7, height = 5)
   trellis.par.set(caretTheme(), warn = FALSE)
   print(xyplot(marsFit, type= c("g", "p", "smooth"), degree = 2))
dev.off()
pdf(paste(getwd(), "/marsDens.pdf", sep = ""), width = 7, height = 5)
   trellis.par.set(caretTheme(), warn = FALSE)
   print(densityplot(marsFit, as.table = TRUE, subset = nprune < 10))
dev.off()


###################################################
### chunk number 27: loadData
###################################################
#line 1969 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
## If we compute the above models, the vignettes takes too long for cran, 
## so we load the data from a remote source
load(url("http://caret.r-forge.r-project.org/Classification_and_Regression_Training_files/exampleModels.RData"))


###################################################
### chunk number 28: resamps
###################################################
#line 1979 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
resamps <- resamples(list(CART = rpartFit,
                          CondInfTree = ctreeFit,
                          MARS = earthFit,
                          M5 = m5Fit))
resamps
summary(resamps)


###################################################
### chunk number 29: resamplePlots
###################################################
#line 2000 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
bwplot(resamps, metric = "RMSE")

densityplot(resamps, metric = "RMSE")

xyplot(resamps,
       models = c("CART", "MARS"),
       metric = "RMSE")

splom(resamps, metric = "RMSE")


###################################################
### chunk number 30: resamplePlots2
###################################################
#line 2012 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
pdf("resampleScatter.pdf", width = 6, height = 6)
trellis.par.set(caretTheme())
print(xyplot(resamps, models = c("CART", "MARS")))
dev.off()
pdf("resampleDens.pdf", width = 7, height = 4.5)
print(
      densityplot(resamps, 
                  scales = list(x = list(relation = "free")), 
                  adjust = 1.2, 
                  plot.points = FALSE, 
                  auto.key = list(columns = 2)))

dev.off() 


###################################################
### chunk number 31: diffs
###################################################
#line 2035 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
difValues <- diff(resamps)

difValues

summary(difValues)


###################################################
### chunk number 32: diffPlots
###################################################
#line 2051 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
dotplot(difValues)

densityplot(difValues,
            metric = "RMSE",
            auto.key = TRUE,
            pch = "|")

bwplot(difValues,
       metric = "RMSE")

levelplot(difValues, what = "differences")


###################################################
### chunk number 33: diffPlots2
###################################################
#line 2065 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
pdf("diffLevel.pdf", width = 7.5, height = 6)
trellis.par.set(caretTheme())
print(levelplot(difValues, what = "differences"))
dev.off()

pdf("diffDot.pdf", width = 6, height = 6)
plotTheme <- caretTheme()
plotTheme$plot.symbol$pch <- 16
plotTheme$plot.line$col <- "black"
trellis.par.set(plotTheme)
print(dotplot(difValues))
dev.off()



###################################################
### chunk number 34: getCp1
###################################################
#line 2289 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
## rpart requires a formula method
tmpData <- bbbDescr
tmpData$logBBB <- logBBB

cpValues10 <- rpart(logBBB ~ ., data = tmpData,
              control = rpart.control(minsplit = 10))$cptable[,"CP"]
cpValues30 <- rpart(logBBB ~ ., data = tmpData,
              control = rpart.control(minsplit = 30))$cptable[,"CP"]
head(cpValues10)


###################################################
### chunk number 35: cpGrid
###################################################
#line 2304 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
rpartGrid <- data.frame(.cp = c(cpValues10, cpValues30),
                        .minsplit = 
                        c(rep(10, length(cpValues10)), 
                          rep(30, length(cpValues30))))



###################################################
### chunk number 36: modelFoo
###################################################
#line 2313 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
modelFunc <- function(data, parameter, levels, last, ...)
  {
    library(rpart)
    ctrl <- rpart.control(cp = parameter$.cp,
                          minsplit = parameter$.minsplit)
    
    list(fit = rpart(.outcome ~ ., data = data, control = ctrl))                             
  }


###################################################
### chunk number 37: predFoo
###################################################
#line 2326 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
predFunc <- function(object, newdata)
  {
    library(rpart)
    predict(object$fit, newdata)                            
  }


###################################################
### chunk number 38: sortFoo
###################################################
#line 2336 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
sortFunc <- function(x)  x[order(x$cp, x$minsplit),]                           


###################################################
### chunk number 39: trControl eval=FALSE
###################################################
## #line 2341 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
## ctrl <- trainControl(custom = list(
##                        parameters = rpartGrid,
##                        model = modelFunc,
##                        prediction = predFunc,
##                        probability = NULL,
##                        sort = sortFunc),
##                      method = "cv")
## 
## set.seed(581)
## customRpart <- train(bbbDescr, logBBB, "custom", trControl = ctrl)


###################################################
### chunk number 40: plotResults eval=FALSE
###################################################
## #line 2359 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
## rpartPlot <- plot(customRpart, xTrans = log10)
## rpartPlot <- update(rpartPlot, xlab = "Complexity Parameter")


###################################################
### chunk number 41: session
###################################################
#line 2369 "d:/Rcompile/CRANpkg/local/2.12/caret/inst/doc/caretTrain.Rnw"
toLatex(sessionInfo())


